==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ConsistentHashLBFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Long;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface ConsistentHashLBFluent<A extends ConsistentHashLBFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildHashKey instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.networking.v1alpha3.ConsistentHashLB.HashKey getHashKey();
    public me.snowdrop.istio.api.networking.v1alpha3.ConsistentHashLB.HashKey buildHashKey();
    public A withHashKey(me.snowdrop.istio.api.networking.v1alpha3.ConsistentHashLB.HashKey hashKey);
    public Boolean hasHashKey();
    public A withHttpCookieHashKey(HttpCookieHashKey httpCookieHashKey);
    public ConsistentHashLBFluent.HttpCookieHashKeyNested<A> withNewHttpCookieHashKey();
    public ConsistentHashLBFluent.HttpCookieHashKeyNested<A> withNewHttpCookieHashKeyLike(HttpCookieHashKey item);
    public A withUseSourceIpHashKey(UseSourceIpHashKey useSourceIpHashKey);
    public ConsistentHashLBFluent.UseSourceIpHashKeyNested<A> withNewUseSourceIpHashKey();
    public ConsistentHashLBFluent.UseSourceIpHashKeyNested<A> withNewUseSourceIpHashKeyLike(UseSourceIpHashKey item);
    public A withNewUseSourceIpHashKey(Boolean useSourceIp);
    public A withHttpHeaderNameHashKey(HttpHeaderNameHashKey httpHeaderNameHashKey);
    public ConsistentHashLBFluent.HttpHeaderNameHashKeyNested<A> withNewHttpHeaderNameHashKey();
    public ConsistentHashLBFluent.HttpHeaderNameHashKeyNested<A> withNewHttpHeaderNameHashKeyLike(HttpHeaderNameHashKey item);
    public A withNewHttpHeaderNameHashKey(String httpHeaderName);
    public Long getMinimumRingSize();
    public A withMinimumRingSize(Long minimumRingSize);
    public Boolean hasMinimumRingSize();
    public A withNewMinimumRingSize(String arg1);
    public A withNewMinimumRingSize(long arg1);

    public interface HttpCookieHashKeyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HttpCookieHashKeyFluent<ConsistentHashLBFluent.HttpCookieHashKeyNested<N>>{

        
    public N and();    public N endHttpCookieHashKey();
}
    public interface UseSourceIpHashKeyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,UseSourceIpHashKeyFluent<ConsistentHashLBFluent.UseSourceIpHashKeyNested<N>>{

        
    public N and();    public N endUseSourceIpHashKey();
}
    public interface HttpHeaderNameHashKeyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HttpHeaderNameHashKeyFluent<ConsistentHashLBFluent.HttpHeaderNameHashKeyNested<N>>{

        
    public N and();    public N endHttpHeaderNameHashKey();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/ConsistentHashLBFluent.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import com.fasterxml.jackson.annotation.JsonUnwrapped;
import java.lang.Boolean;

public interface ConsistentHashLBFluent<A extends ConsistentHashLBFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildHashKey instead.
 * @return The buildable object.
 */
@Deprecated public ConsistentHashLB.HashKey getHashKey();
    public ConsistentHashLB.HashKey buildHashKey();
    public A withHashKey(ConsistentHashLB.HashKey hashKey);
    public Boolean hasHashKey();
    public A withHttpCookieHashKey(HttpCookieHashKey httpCookieHashKey);
    public ConsistentHashLBFluent.HttpCookieHashKeyNested<A> withNewHttpCookieHashKey();
    public ConsistentHashLBFluent.HttpCookieHashKeyNested<A> withNewHttpCookieHashKeyLike(HttpCookieHashKey item);
    public A withUseSourceIpHashKey(UseSourceIpHashKey useSourceIpHashKey);
    public ConsistentHashLBFluent.UseSourceIpHashKeyNested<A> withNewUseSourceIpHashKey();
    public ConsistentHashLBFluent.UseSourceIpHashKeyNested<A> withNewUseSourceIpHashKeyLike(UseSourceIpHashKey item);
    public A withNewUseSourceIpHashKey(Boolean useSourceIp);
    public A withHttpHeaderNameHashKey(HttpHeaderNameHashKey httpHeaderNameHashKey);
    public ConsistentHashLBFluent.HttpHeaderNameHashKeyNested<A> withNewHttpHeaderNameHashKey();
    public ConsistentHashLBFluent.HttpHeaderNameHashKeyNested<A> withNewHttpHeaderNameHashKeyLike(HttpHeaderNameHashKey item);
    public A withNewHttpHeaderNameHashKey(String httpHeaderName);
    public Integer getMinimumRingSize();
    public A withMinimumRingSize(Integer minimumRingSize);
    public Boolean hasMinimumRingSize();

    public interface HttpCookieHashKeyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HttpCookieHashKeyFluent<ConsistentHashLBFluent.HttpCookieHashKeyNested<N>>{

        
    public N and();    public N endHttpCookieHashKey();
}
    public interface UseSourceIpHashKeyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,UseSourceIpHashKeyFluent<ConsistentHashLBFluent.UseSourceIpHashKeyNested<N>>{

        
    public N and();    public N endUseSourceIpHashKey();
}
    public interface HttpHeaderNameHashKeyNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,HttpHeaderNameHashKeyFluent<ConsistentHashLBFluent.HttpHeaderNameHashKeyNested<N>>{

        
    public N and();    public N endHttpHeaderNameHashKey();
}


}
